---
jupyter:
  kernel_info:
    name: python3
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

```{python inputHidden=FALSE, outputHidden=FALSE, tags=c("parameters")}
param = 4
```

```{python inputHidden=FALSE, outputHidden=FALSE}
import pandas as pd
```

```{python inputHidden=FALSE, outputHidden=FALSE}
df = pd.DataFrame({'A': [1, 2], 'B': [3 + param, 4]},
                  index=pd.Index(['x0', 'x1'], name='x'))
df
```

```{python inputHidden=FALSE, outputHidden=FALSE}
# %matplotlib inline
df.plot(kind='bar')
```
